#![allow(non_snake_case)]

use js_sys::Array;

use wasm_bindgen::{prelude::*, JsCast, JsValue};
use web_sys::{
    Blob, HtmlAnchorElement, HtmlDialogElement, HtmlElement, HtmlFormElement, HtmlInputElement, Url,
};
use yew::prelude::*;
use yewdux::prelude::*;

use crate::components::states::{CurrentTransfer, MainState};

use crate::state_to_csv;

type NoParamsCallback = Box<dyn Fn(())>;

pub fn new_plate_dialog_callback(
    new_plate_dialog_is_open: UseStateHandle<bool>,
) -> NoParamsCallback {
    let new_plate_dialog_is_open = new_plate_dialog_is_open.clone();
    Box::new(move |_| {
        new_plate_dialog_is_open.set(false);
    })
}

pub fn open_new_plate_dialog_callback(
    new_plate_dialog_is_open: UseStateHandle<bool>,
) -> NoParamsCallback {
    let new_plate_dialog_is_open = new_plate_dialog_is_open.clone();
    Box::new(move |_| {
        new_plate_dialog_is_open.set(true);
    })
}

pub fn new_button_callback(
    main_dispatch: Dispatch<MainState>,
    ct_dispatch: Dispatch<CurrentTransfer>,
) -> Callback<web_sys::MouseEvent> {
    Callback::from(move |_| {
        let window = web_sys::window().unwrap();
        let confirm =
            window.confirm_with_message("This will reset all plates and transfers. Proceed?");
        if let Ok(confirm) = confirm {
            if confirm {
                main_dispatch.set(MainState::default());
                ct_dispatch.set(CurrentTransfer::default());
            }
        }
    })
}
